@@ -102,7 +102,7 @@ class Subtitle:
 def clean(subs, expressions):
     # Cancel if no expression
     if len(expressions) == 0:
-        return
+        return subs
 
     # Remove lines matching any expression
     for regexp in expressions:
@@ -183,6 +183,32 @@ def process_file(args, file, expressions):
     output.close()
 
 
+def read_expressions(args):
+    if args.clean:
+        cfg = args.config_file
+
+        # Open default config file if not specified
+        if not args.config_file:
+            home = pathlib.Path.home()
+            try:
+                if type(home) is pathlib.PosixPath:
+                    cfg = open(str(home) + '/.config/fsubrc', 'r')
+                elif type(home) is pathlib.WindowsPath:
+                    cfg = open(os.getenv('APPDATA') + r'\fsubrc', 'r')
+                else:
+                    print('Unsupported operating system', file=sys.stderr)
+                    sys.exit(1)
+            except FileNotFoundError:
+                return []
+
+        # Read expressions
+        lines = re.split(r'\r?\n', cfg.read().strip())
+        expressions = list(map(re.compile, lines))
+        cfg.close()
+        return expressions
+    return []
+
+
 def main():
     parser = argparse.ArgumentParser(
         description='Fix, edit and clean SubRip (.srt) files.',
@@ -214,8 +240,8 @@ def main():
 
     parser.add_argument(
         '-f', '--config-file',
-        help='overwrite the default config file (Unix: $HOME/.config/fsubrc, ' +
-             r'Windows: %%APPDATA%%\fsubrc)',
+        help='overwrite the default config file (Unix: $HOME/.config/fsubrc,' +
+             r' Windows: %%APPDATA%%\fsubrc)',
         metavar='FILE',
         action='store',
         type=argparse.FileType('r')
@@ -247,25 +273,7 @@ def main():
                   file=sys.stderr)
             sys.exit(1)
 
-    expressions = []
-    if args.clean:
-        cfg = args.config_file
-
-        # Open default config file if not specified
-        if not args.config_file:
-            home = pathlib.Path.home()
-            if type(home) is pathlib.PosixPath:
-                cfg = open(str(home) + '/.config/fsubrc', 'r')
-            elif type(home) is pathlib.WindowsPath:
-                cfg = open(os.getenv('APPDATA') + r'\fsubrc', 'r')
-            else:
-                print('Unsupported operating system', file=sys.stderr)
-                sys.exit(1)
-
-        # Read expressions
-        lines = re.split(r'\r?\n', cfg.read().strip())
-        expressions = list(map(re.compile, lines))
-        cfg.close()
+    expressions = read_expressions(args)
 
     for file in args.files:
         process_file(args, file, expressions)
